package com.srs.teacher.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.srs.teacher.mapper.SysTeacherTakeclassMapper;
import com.srs.teacher.domain.SysTeacherTakeclass;
import com.srs.teacher.service.ISysTeacherTakeclassService;

/**
 * takeClassService业务层处理
 *
 * @author srs
 * @date 2024-05-29
 */
@Service
public class SysTeacherTakeclassServiceImpl extends ServiceImpl<SysTeacherTakeclassMapper,SysTeacherTakeclass> implements ISysTeacherTakeclassService {
    @Autowired
    private SysTeacherTakeclassMapper sysTeacherTakeclassMapper;

    /**
     * 查询takeClass
     *
     * @param takeclassId takeClass主键
     * @return takeClass
     */
    @Override
    public SysTeacherTakeclass selectSysTeacherTakeclassByTakeclassId(Long takeclassId) {
        return sysTeacherTakeclassMapper.selectSysTeacherTakeclassByTakeclassId(takeclassId);
    }

    /**
     * 查询takeClass列表
     *
     * @param sysTeacherTakeclass takeClass
     * @return takeClass
     */
    @Override
    public List<SysTeacherTakeclass> selectSysTeacherTakeclassList(SysTeacherTakeclass sysTeacherTakeclass) {
        return sysTeacherTakeclassMapper.selectSysTeacherTakeclassList(sysTeacherTakeclass);
    }

    /**
     * 新增takeClass
     *
     * @param sysTeacherTakeclass takeClass
     * @return 结果
     */
    @Override
    public int insertSysTeacherTakeclass(SysTeacherTakeclass sysTeacherTakeclass) {
            return sysTeacherTakeclassMapper.insertSysTeacherTakeclass(sysTeacherTakeclass);
    }

    /**
     * 修改takeClass
     *
     * @param sysTeacherTakeclass takeClass
     * @return 结果
     */
    @Override
    public int updateSysTeacherTakeclass(SysTeacherTakeclass sysTeacherTakeclass) {
        return sysTeacherTakeclassMapper.updateSysTeacherTakeclass(sysTeacherTakeclass);
    }

    /**
     * 批量删除takeClass
     *
     * @param takeclassIds 需要删除的takeClass主键
     * @return 结果
     */
    @Override
    public int deleteSysTeacherTakeclassByTakeclassIds(Long[] takeclassIds) {
        return sysTeacherTakeclassMapper.deleteSysTeacherTakeclassByTakeclassIds(takeclassIds);
    }

    /**
     * 删除takeClass信息
     *
     * @param takeclassId takeClass主键
     * @return 结果
     */
    @Override
    public int deleteSysTeacherTakeclassByTakeclassId(Long takeclassId) {
        return sysTeacherTakeclassMapper.deleteSysTeacherTakeclassByTakeclassId(takeclassId);
    }
}
